@@ -1392,25 +1392,13 @@ class Client(Callbacks, SocketHandler):
         else: return response.status_code
 
     def join_community(self, comId: str, invitationId: str = None):
-        """
-        Join a Community.
-
-        **Parameters**
-            - **comId** : ID of the Community.
-            - **invitationId** : ID of the Invitation Code.
-
-        **Returns**
-            - **Success** : 200 (int)
-
-            - **Fail** : :meth:`Exceptions <amino.lib.util.exceptions>`
-        """
-        data = {"timestamp": int(timestamp() * 1000)}
-        if invitationId: data["invitationId"] = invitationId
-
-        data = json.dumps(data)
-        response = requests.post(f"{self.api}/x{comId}/s/community/join", data=data, headers=self.parse_headers(data=data), proxies=self.proxies, verify=self.certificatePath)
-        if response.status_code != 200: return exceptions.CheckException(json.loads(response.text))
-        else: return response.status_code
+        url = f"{self.api}/x{comId}/s/community/join"
+        self.headers["Content-Type"] = "application/json"
+        response = requests.post(url=url, headers=self.headers, verify=self.certificatePath)
+        if response.status_code != 200:
+            return exceptions.CheckException(json.loads(response.text))
+        else:
+            return response.status_code
 
     def request_join_community(self, comId: str, message: str = None):
         """
